#
# spec file for package amazon-ssm-agent
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           amazon-ssm-agent
Version:        3.3.551.0
Release:        bp160.1.5
Summary:        Amazon Remote System Config Management
License:        Apache-2.0
Group:          System/Management
URL:            https://github.com/aws/amazon-ssm-agent
Source0:        https://github.com/aws/amazon-ssm-agent/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  go >= 1.21
BuildRequires:  pkgconfig(systemd)
Requires:       systemd
Provides:       bundled(golang(github.com/Microsoft/go-winio))
Provides:       bundled(golang(github.com/Workiva/go-datastructures))
Provides:       bundled(golang(github.com/aws/aws-sdk-go))
Provides:       bundled(golang(github.com/carlescere/scheduler))
Provides:       bundled(golang(github.com/cenkalti/backoff))
Provides:       bundled(golang(github.com/cihub/seelog))
Provides:       bundled(golang(github.com/coreos/go-semver))
Provides:       bundled(golang(github.com/creack/pty))
Provides:       bundled(golang(github.com/davecgh/go-spew))
Provides:       bundled(golang(github.com/emirpasic/gods))
Provides:       bundled(golang(github.com/fsnotify/fsnotify))
Provides:       bundled(golang(github.com/gabs))
Provides:       bundled(golang(github.com/go-git/gcfg))
Provides:       bundled(golang(github.com/go-git/go-billy))
Provides:       bundled(golang(github.com/go-git/go-git))
Provides:       bundled(golang(github.com/go-github))
Provides:       bundled(golang(github.com/go-ini/ini))
Provides:       bundled(golang(github.com/go-yaml/yaml))
Provides:       bundled(golang(github.com/google/go-querystring))
Provides:       bundled(golang(github.com/google/shlex))
Provides:       bundled(golang(github.com/gorhill/cronexpr))
Provides:       bundled(golang(github.com/gorilla/websocket))
Provides:       bundled(golang(github.com/hectane/go-acl))
Provides:       bundled(golang(github.com/imdario/mergo))
Provides:       bundled(golang(github.com/jbenet/go-context))
Provides:       bundled(golang(github.com/jmespath/go-jmespath))
Provides:       bundled(golang(github.com/kevinburke/ssh_config))
Provides:       bundled(golang(github.com/lsegal/gucumber))
Provides:       bundled(golang(github.com/mitchellh/go-homedir))
Provides:       bundled(golang(github.com/mitchellh/go-ps))
Provides:       bundled(golang(github.com/nightlyone/lockfile))
Provides:       bundled(golang(github.com/pborman/ansi))
Provides:       bundled(golang(github.com/pmezard/go-difflib))
Provides:       bundled(golang(github.com/sergi/go-diff))
Provides:       bundled(golang(github.com/shiena/ansicolor))
Provides:       bundled(golang(github.com/stretchr/objx))
Provides:       bundled(golang(github.com/stretchr/testify))
Provides:       bundled(golang(github.com/twinj/uuid))
Provides:       bundled(golang(github.com/xanzy/ssh-agent))
Provides:       bundled(golang(github.com/xtaci/smux))
Provides:       bundled(golang(go.nanomsg.org/mangos))
Provides:       bundled(golang(golang.org/x/crypto))
Provides:       bundled(golang(golang.org/x/net))
Provides:       bundled(golang(golang.org/x/oauth2))
Provides:       bundled(golang(golang.org/x/sync))
Provides:       bundled(golang(golang.org/x/sys))
Provides:       bundled(golang(gopkg.in/warnings.v0))

ExclusiveArch:  aarch64 x86_64

%description
This package provides the Amazon SSM Agent for managing EC2 Instances using
Amazon EC2 Systems Manager (SSM).

The SSM Agent runs on EC2 or on-premise instances and enables you to quickly
and easily execute remote commands or scripts against one or more instances.
When you execute a command, the agent on the instance processes the document
and configures the instance as specified.

This collection of capabilities helps you automate management tasks such as
collecting system inventory, applying operating system (OS) patches, automating
the creation of Amazon Machine Images (AMIs), and configuring operating systems
(OSs) and applications at scale. Systems Manager works with managed instances:
Amazon EC2 instances, or servers and virtual machines (VMs) in your on-premises
environment that are configured for Systems Manager.

%prep
%setup -q
sed -i -e 's#const[ \s]*Version.*#const Version = "%{version}"#g' agent/version/version.go
sed -i 's#/bin/#/sbin/#' packaging/linux/amazon-ssm-agent.service
sed -i 's#var defaultWorkerPath = "/usr/bin/"#var defaultWorkerPath = "/usr/sbin/"#' agent/appconfig/constants_unix.go

%build
export GO111MODULE="auto"
cp -r Tools agent common core internal packaging vendor src

PKG_ROOT=`pwd`
GOPATH=${PKG_ROOT}/vendor:${PKG_ROOT}
ln -s ${PKG_ROOT} ${PKG_ROOT}/vendor/github.com/aws/aws-sdk-go
export GOPATH

CGO_ENABLED=0 go build -ldflags "-s -w -extldflags=-Wl,-z,now,-z,relro,-z,defs" -buildmode=pie -o bin/amazon-ssm-agent -v core/agent.go core/agent_unix.go core/agent_parser.go
CGO_ENABLED=0 go build -ldflags "-s -w -extldflags=-Wl,-z,now,-z,relro,-z,defs" -buildmode=pie -o bin/ssm-agent-worker -v agent/agent.go agent/agent_unix.go agent/agent_parser.go
CGO_ENABLED=0 go build -ldflags "-s -w -extldflags=-Wl,-z,now,-z,relro,-z,defs" -buildmode=pie -o bin/ssm-document-worker -v agent/framework/processor/executer/outofproc/worker/main.go
CGO_ENABLED=0 go build -ldflags "-s -w -extldflags=-Wl,-z,now,-z,relro,-z,defs" -buildmode=pie -o bin/ssm-session-worker -v agent/framework/processor/executer/outofproc/sessionworker/main.go
CGO_ENABLED=0 go build -ldflags "-s -w -extldflags=-Wl,-z,now,-z,relro,-z,defs" -buildmode=pie -o bin/ssm-session-logger -v agent/session/logging/main.go
CGO_ENABLED=0 go build -ldflags "-s -w -extldflags=-Wl,-z,now,-z,relro,-z,defs" -buildmode=pie -o bin/ssm-cli -v agent/cli-main/cli-main.go

%install
install -d -m 755 %{buildroot}%{_sbindir}
install -d -m 755 %{buildroot}%{_sysconfdir}/amazon/ssm
install -d -m 755 %{buildroot}%{_localstatedir}/log/amazon/ssm
install -d -m 755 %{buildroot}%{_localstatedir}/lib/amazon/ssm
install -m 755 bin/amazon-ssm-agent %{buildroot}%{_sbindir}
install -m 755 bin/ssm-agent-worker %{buildroot}%{_sbindir}
install -m 755 bin/ssm-cli %{buildroot}%{_sbindir}
install -m 755 bin/ssm-document-worker %{buildroot}%{_sbindir}
install -m 755 bin/ssm-session-worker %{buildroot}%{_sbindir}
install -m 755 bin/ssm-session-logger %{buildroot}%{_sbindir}

mkdir -p %{buildroot}%{_unitdir}
cp seelog_unix.xml %{buildroot}%{_sysconfdir}/amazon/ssm/seelog.xml.template
cp amazon-ssm-agent.json.template %{buildroot}%{_sysconfdir}/amazon/ssm/
install -m 644 packaging/linux/amazon-ssm-agent.service %{buildroot}%{_unitdir}

%files
%defattr(-,root,root,-)
%dir %{_sysconfdir}/amazon
%dir %{_sysconfdir}/amazon/ssm
%dir %{_localstatedir}/log/amazon
%dir %{_localstatedir}/lib/amazon
%license LICENSE
%doc CONTRIBUTING.md NOTICE.md README.md RELEASENOTES.md
%config(noreplace) %{_sysconfdir}/amazon/ssm/amazon-ssm-agent.json.template
%config(noreplace) %{_sysconfdir}/amazon/ssm/seelog.xml.template
%{_sbindir}/*
%{_unitdir}/%{name}.service
%{_localstatedir}/lib/amazon/ssm
%ghost %{_localstatedir}/log/amazon/ssm/

%pre
%service_add_pre %{name}.service

%preun
%service_del_preun %{name}.service

%post
%service_add_post %{name}.service

%postun
%service_del_postun %{name}.service

%changelog
* Tue Jul  2 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 3.3.551.0
  * Agent updater attempts yum install/uninstall before falling
    back to attempt with rpm
  * Updated golang.org/x/net from v0.19.0 to v0.26.0
  * Upgrade GoLang to version 1.21.11
  * Add IPv6 addresses for NTP and EC2Config to default DenyList
  * Update Distributor to only use Systems Manager APIs to fetch package contents
- from version 3.3.484.0
  * Update SSM-Setup-CLI logs related to checksum validation of latest version
- from version 3.3.418.0
  * Upgrade go-github version from v8 to v61
  * Increase timeouts in SSM-Setup-CLI
  * Fix darwin build issue in SSM-Setup-CLI
  * Fix the command builder bug to handle space char in input value
  * Fix an inaccurate log when validating allowDowngrade parameter during Agent update
  * Signing SSM Agent vended Windows executables
- from version 3.3.380.0
  * Update AWS GO SDK to v1.51.20
- from version 3.3.337.0
  * Remove yum as package manager in linux install/uninstall script
  * Verify TrustedInstaller status before posting WindowsUpdate
    information in aws:softwareInventory plugin
* Fri Apr  5 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 3.3.217.0
  * Add alternative outputs for agent package generation scripts
  * Add support for Oracle 8.8 & 8.9, Rocky 8.8 & 8.9,
    AlmaLinux 8.8 & 8.9, and RHEL 8.9 & 9.3
  * Fix flaky integration test
  * Fix setup-cli error code for non English systems
  * Set IPR creds expiry to 30 mins for ssm agent worker
  * Switch installer package manager from rpm to yum on OSes that support yum
  * Upgrade GoLang to version 1.21.8
- from version 3.3.131.0
  * Add integration tests for control channel and data channel module
  * Remove data channel and control channel acknowledgement
    functionality in MGS Interactor
- from version 3.2.2303.0
  * Add integration tests for control channel module
  * Revert data channel and control channel acknowledgement
    functionality in MGS Interactor
  * Update Greengrass component minor version to 1.2.4
* Tue Feb 13 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 3.3.40.0
  * Fix issue to execute aws:updateSSMAgent plugin through aws:rundocument plugin
  * Update Messaging module to switch off ec2messages
    when ssmmessages connected successfully
  * Update SSM Agent Minor version from 3.2 to 3.3
- from version 3.2.2222.0
  * Upgrade minimum go version in go.mod file to go 1.19
  * Upgrade go-git package to v5.11.0
  * Fix for bad default manifest url when updating EC2Config
- from version 3.2.2143.0
  * Fixed plugin path traversal logic
  * Updated aws:application plugin default param
  * Fixed default param in psmodule
  * Upgraded GoLang to version 1.21.5
- from version 3.2.2086.0
  * Added Agent config to configure session logs destination
  * Added data channel acknowledgement functionalities
  * Added redirect handler and timeout for HTTP client
  * Added steps to verify aws-cli installation for domainJoin plugin
  * Added support for Ubuntu 23.04, Debian 11.7 & 12, and SUSE 15.5
  * Adjusted random number generator logic used to get filename in downloadContent plugin
  * Fixed Agent to gather application inventory from both rpm and
    dpkg package managers if present in Unix instances
  * Bump golang.org/x/crypto/ssh from 0.14.0 to 0.17.0
- from version 3.2.2016.0
  * Added telemetry for agent core in-proc executor usage
  * Added retries for Agent installation with snap on Greengrass
  * Added code to update Agent config to use only Onprem Identity in Greengrass
  * Added support for macOS 14 (Sonoma)
  * Added Onprem registration support using ssm-setup-cli
  * Fixed docker installation issues in aws:configureDocker plugin
  * Fix for document worker and session worker not logging when
    custom seelog configuration missing parameters
  * Updated allowed regex pattern in S3 URI
  * Update Agent IoT Greengrass component minor version
  * Updated SUSE version in Seamless Domain Join script
  * Updated Greengrass component workflow to get installed Agent version and update
    Agent only when the installed Agent version doesn't match with Greengrass
    component Agent version
  * Upgraded GoLang version that builds agent binaries with to 1.20.11
- Update Go version requirement to 1.21
* Mon Dec 11 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 3.2.1798.0
  * Bump golang.org/x/net from 0.15.0 to 0.17.0
  * Upgraded GoLang to version 1.20.10
  * Fixing race condition in session datachannel unit test
- from version 3.2.1705.0
  * Updated MGS Interactor to send 'Failed' status on agentJob parsing error
  * Added error handling for Linux DomainJoin when service account credentials empty
  * Fix for panic scenario in when running aws:configureDocker plugin
  * Upgraded GoLang to version 1.20.8
  * Upgraded golang.org/x/net to v0.15.0
  * Added support for macOS 13 (Ventura)
- from version 3.2.1630.0
  * Fix credential retrieval retry logic in credential refresher
  * Reducing retrieval log level to debug in the credential
    refresher after more than 3 retrieval retries
  * Fix for EC2 credential retrieval errors not being
    propagated to the credential refresher
  * Fixing agent version input format validation
  * Fix downloadPlatformOverride for AlmaLinux
  * Fixed issue where removing seelog.xml file doesn't
    revert minimum log level back to INFO
  * Ignore non-audit files in audit folder
- from version 3.2.1542.0
  * Add aws:updateSSMAgent plugin support for Flatcar Linux
  * Add fix to resolve manifest url during agent update when using stable keyword
  * Fix multiple issues causing tight loops during IPC connection scenarios
  * Sign deb and rpm installer packages for Linux instances using new key
  * Use file based IPC by default for amazon-ssm-agent
    and ssm-agent-worker communication in Darwin
* Thu Aug 17 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 3.2.1478.0
  * Added fix to propagate exit code properly when command fails to start
  * Added control channel acknowledgement functionalities
  * Added flag to specify go version used for gosec and
    govulncheck in static analysis script
  * Added support for RHEL 8.7, 8.8, 9.1, 9.2
  * Added support for Rocky Linux 8.7, 9.0, 9.1, 9.2
  * Added support for Oracle Linux 8.7, 9.1, 9.2
  * Update go version to 1.20.7
- from version 3.2.1377.0
  * Stopped saving instance profile credentials to disk
  * Added static agent security scans to makefile
  * Updated Greengrass component minor version
- from version 3.2.1297.0
  * Added retries to snap uninstall call in setupcli
  * Fix for windows shutdown executable not found when compiled with golang1.19+
  * Fix to return correct Agent Job ID for ack after AgentJobParseError
  * Pass golang contexts for network calls in agent core to terminate cleanly
  * Remove credential file dependency in agent workers implemented in 3.2.x.x versions
  * Report MGS Connection Channel status to Health table
  * Update Dockerfile to use Golang image from ECR repository
- from version 3.2.1241.0
  * Get bucket region using signed HeadBucket request
  * Updated golang.org/x/net version to 0.10.0 and
    golang.org/x/crypto version to 0.9.0
  * Update go version to 1.19.10
- from version 3.2.1041.0
  * Add retry to handle stream data acknowledge messages
  * Support latest as a version in configurePackage plugin
  * Updated AWS GO SDK to v1.44.261 and disabled IMDSv1 fallback logic
  * Use IP address to connect to destination server in port session
- from version 3.2.985.0
  * Add Domain Join support for RHEL 8.7 and AL2022
  * Add Support to send aws:updateSSMAgent replies through MGS
  * Retrieve and set interface name dynamically in
    aws:domainJoin plugin for Ubuntu
* Mon May 22 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 3.2.923.0
  * Update Dockerfile Go version to 1.19
  * Add reporting of MGS connection status
  * Add support for updating to agent version marked stable
  * Add status code to MGS ack and send on message process failure
  * Update golangci-lint configuration
  * Add e2e tag to session shell tests
* Sun Apr 16 2023 Dirk Müller <dmueller@suse.com>
- update to 3.2.815.0:
  * Add EC2 credential fallback for AssumeRoleUnauthorizedAccess
    error
  * Add CloudWatch log upload support for document and session
    worker
  * Add set-hostname support in domainjoin plugin for windows
  * Add wait time in Agent updater to avoid installation issues
    caused during reboots initiated by domainjoin plugin
  * Add support for AlmaLinux
  * Fix KeepHostName parameter without DNS IP address parameter
    in domainJoin plugin
  * Fix issue where carriage returns cause json conversion to
    fail in aws:softwareInventory plugin
  * Remove IMDS calls in Onprem during health check
  * Remove S3 global endpoint fallback logic
  * Update cli descriptions for registration parameters
  * Update go version to 1.19.6
- update to 3.2.582.0:
  * Modified EC2 credential fallback logic
- update to 3.2.574.0:
  * Fixed go-vet issues by passing mocks by value
  * Updated domainjoin and cloudwatch executables for windows
- update to 3.2.532.0:
  * Removed explicit setting of EC2 aws credential profile
  * Added public key to registration info
  * Sends non-interactive command errors that occur before
    command execution to data channel
  * Added instance id verification to registration process
* Fri Jan 13 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 3.2.419.0
  + Added minimum retry sleep for Registrar RegisterManagedInstance calls
  + Explicitly skip AZ info check for on-prem and ECS targets
  + Fix for SSM-Agent that is unable to start on Apple Mac M1's (mac2.metal instances)
  + Ensuring powershell path is set to system directory on Windows
  + Load DLLs with using system/absolute paths on Windows
  + Added workaround for Samba limit when loading Active Directory ids
  + Dynamically get network interface name for SeamlessDomainJoin
  + Added install-yum-rpm to makefile to install agent on host from source code
  + Added logging for specifying credential source
  + Refactored tests to remove mocks from production binaries
  + Updated Windows DomainJoin plugin SharpZipLib and Newtonsoft.json dependencies
- from version 3.2.345.0
  + Updated yaml.v3 dependency
* Wed Nov 23 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 3.2.286.0
  + Separated EC2 identity vault manifest from OnPrem identity vault manifest
  + Fix for credential retrieval blocking os termination signals
  + Fix for agent updater using shared credentials on EC2
  + Added guards against panic for agent identity health checks
  + Added logging around agent module start/stop
- from version 3.2.183.0
  + Added logging when assuming identity
  + Increased retries to ECS metadata endpoint
  + Added linux debug build to makefile
  + Implemented aws sdk logging interface
  + Updated agent minor version to 3.2
  + Added functionality to retrieve agent credentials from Systems Manager on EC2
- from version 3.1.1927.0
  + Update shell for Session Manager on MacOS
* Tue Nov  1 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 3.1.1856.0
  + Lower message length threshold for cloudwatch log streaming
  + Ran gofmt and goimports with golang version 1.19
  + Report AvailabilityZone and AvailabilityZoneId in health pings
  + Update AWS Go SDK to v1.44.78
  + from version 3.1.1767.0
  + Fix samba configuration for sub-domains
  + from version 3.1.1732.0
  + Add code in document/session worker to fallback to default
    identity selector when runtime config not present
  + Fix to handle command-line-arguments in document/session
    worker when launched by old agent workers
- from version 3.1.1634.0
  + Fallback to file based IPC if named pipe creation times out
  + Increase tls handshake timeout in http download client
  + Log mds client timeout errors as WARN
- from version 3.1.1575.0
  + Added separate metric for snapd running apps failure during update
  + Fixed idle session timeout with smux keep alive configuration based on CLI version
  + Updated AgentTaskComplete message retry
  + Updated go version to 1.18.3
- from version 3.1.1511.0
  + Collect kernel version in InstanceDetailedInformation
  + Support separate output stream for non-interactive session
  + Cleanup default log group name for runcommands
  + Updated rpm spec file to include build id
- from version 3.1.1476.0
  + Fix port session premature close when local server is not connected before timeout
- from version 3.1.1446.0
  + Add created date to AgentJobAck message
  + Disable smux keep alive to use idle session timeout feature
  + Fix unit-tests running on windows
- from version 3.1.1374.0
  + Added timeout for s3 HEAD requests
  + Added vpc address deny to port forwarding
  + Fixed for reboot scenario in configure package plugin
  + Fixed goroutine leak in seelog library
  + Fixed nullpointer segmentation fault in configure package plugin
  + Improved error handling in manifest download in updater
  + Improved worker initialization to improve startup failure logging
* Thu Apr 21 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Fix mangled ExlusiveArch field
* Wed Apr 20 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 3.1.1260.0
  + Added missing check for invalid S3 path parameter
  + Added support for domain join using a non-local username
  + Fixed broken links in README.md
  + Fixed ECS Exec issue where agent was using environment variables for credentials
  + Updated Ec2Detector test to query smbios directly for system information
- from version 3.1.1208.0
  + Updated ec2detector module to use Get-CmiInstance instead of wmic.exe
  + Fixed file creation mode of ssm-agent-users sudoer file (bsc#1196556, CVE-2022-29527)
- from version 3.1.1188.0
  + Added new ec2detector module to determine if agent is on EC2
  + Added support for port forwarding to remote host
  + Added quotes around inventory parameter ValueName on Windows
  + Fix for domain join DNS IP assignments in shared directories
  + Replaced namedpipe updater test with ec2detector test
- from version 3.1.1141.0
  + Add application inventory by file for Bottlerocket
  + Fix infinite retry logic to send failed replies in MGSInteractor
  + Remove usage of io/fs package
- from version 3.1.1080.0
  + (windows only) Remove symlink scan during update
- from version 3.1.1045.0
  + Fixed sourceHash validation for aws:application document plugin
  + Added document parameter validation for values passed to target document of aws:runDocument plugin
  + (windows only) Fix process leak when legacy cloudwatch plugin is enabled
  + (windows only) Fail installation if C:\ProgramData\Amazon\SSM\ has symlinks
- from version 3.1.1004.0
  + Added platform detection for Bottlerocket OS
  + Consolidated regional endpoint generation to common endpoint module
- from version 3.1.941.0
  + Added support for Rocky linux
  + Fixed sharefile/shareprofile not being propagated to updateutil
  + Fixed incorrect darwin platform detection post BigSur
  + Fixed log flush issue in updater
  + Updated .NET dependencies for domainjoin and cloudwatch (windows only)
  + Updated go version to 1.17.6
- from version 3.1.821.0
  + Implement new core module named MessageService to start processing commands from both MGS and MDS
  * Merge functionalities from RunCommandService core module and Session core module.
  * Receive run command documents through MGS if connected and fallback to MDS otherwise.
    This functionality requires appropriate permissions for both endpoints and will be rolled
    out gradually to end users.
  * Provide filesystem based idempotency check to avoid duplicate run command document execution.
  * Increase default run command pool buffer size from 1 to 5 to load additional documents
    before-hand for processing.
  + Fix nil pointer deference panic produced in named pipe test case during agent update
  + Remove StopType concept in ssm-agent-worker and add different waits for reboot and shutdown stop
- from version 3.1.804.0
  + Add support for upstart when running get-diagnostic command using ssm-cli
  + Fix systemctl service name to support older versions of systemctl
  + Include changes to facilitate testing
  + Update DNS server selection logic for seamless domain join on linux and darwin
  + Update go version to go1.17.5
  + Update golang sys package dependency
- from version 3.1.715.0
  + Derive default directories from appconfig on Darwin
  + Set x-bit on newly-created directories
- from version 3.1.634.0
  + Fix for ssm-setup-cli to be able to select service manager without the agent being installed
- from version 3.1.630.0
  + Added greengrass component recipe for the new SystemsManagerAgent component
  + Added support for registering agent on a greengrass device
  + Added support for downloading more than 1000 objects in downloadContent
  + Fixed retry logic for onprem and s3 upload
  + Fixed unit tests when running on Mac
  + Update AWS SDK to v1.41.4
  + Update logic to retrieve platform details for Rocky Linux
- from version 3.1.501.0
  + Add diagnostics command to ssm-cli
  + Fix caching for onprem credentials
  + Additional configuration options for Seamless Domain Join
  + Gracefully exit session if group of runas user is modified
  + Skip retries for cert validation errors in S3 HEAD requests
  + Fix DNS failures on CentOS 8.2
  + Update several dependencies
- from version 3.1.459.0
  + Fixed a bug with powershell command for Inventory
- from version 3.1.426.0
  + Fixed cpu spike issue manifesting on snap
  + Fixed issue with version comparison in EC2Config update plugin
  + Fixed panic when command output was being truncated
  + Updated build to use go1.16.8
  + Removed Profile from inventory powershell commands on Windows
- from version 3.1.338.0
  + Fix to eliminate WaitGroup reuse panic triggered during agent reboot
  + Fix to include applications without UninstallString in Inventory for Windows
  + Fixed a bug where multi-plugin documents with large outputs would timeout RunCommand
  + Fixed a bug where RunCommand could delay executions for up to 15 minutes
- from version 3.1.282.0
  + Add serial port logging of AwsNitroEnclaves package version on windows during startup
  + Allow usage of existing loggroup/logstream when the user does not have create permission
  + Change service interrogate request log to debug
  + Cleanup old surveyor channel files on startup
  + Fix filehandle leak in windows leading to agent going offline
  + Fix to schedule correct next run time during orchestration directories cleanup
  + Fix to sequentially update correct runcount value in the document bookkeeping file
  + Fix a bug with version parsing EC2Config updater
  + Updated rpm packaging for fips compliance
- from version 3.1.192.0
  + Added darwin arm64 to makefile
  + Added logic to limit orchestration directory cleanup
  + Added packaging for public SSM Agent container image
  + Fixed cloudwatch endpoint for telemetry metrics requests
  + Fixed handling of Windows filepaths and mutex locks
  + Fixed agent worker handling of OS signals and termination channel requests
  + Updated datachannel retry strategy to not retry for a specific error scenario
  + Updated default gomaxproc value for Windows
  + Update build to use go1.16.6
- from version 3.1.127.0
  + Added a workaround for windows random halts
  + Fixed race condition during reboot document execution
- from version 3.1.90.0
  + Updated to version 3.1
  + Updated build to build statically linked binaries for linux 64bit
  * Minimum supported linux kernel version for linux 64bit is 3.2+
  + Fixed permissions for docker config file
  + Fixed issue with ubuntu prerm and postinst scripts
  + Fixed issue where processor stop was being called twice
- from version 3.0.1390.0
  + Added config option to delete orchestration folder
  + Added snapcraft packaging config
  + Added workaround for aws:runDocument status bug
  + Added improved handling of file closure
  + Added support for go mod and updated build to use go 1.16.4
  + Fixed bug parsing vpce s3 urls
  + Refactored use of agent identity in agent cli
  + Updated check if agent is running as windows service
  + Updated handling of session cancellation to still send output to client side
  + Updated interactive session exit code logic to match non-interactive mode
  + Updated vendor dependencies
- Update directory path for GOPATH
* Fri Jun 25 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 3.0.1295.0
  + Added configurable custom identity and identity consumption order
  + Added cross-account domain join
  + Added cleanup for older versions of updater artifacts
  + Added a workaround for MacOS kernel bug that sometimes kept RunCommand from launching
  + Added a workaround for log file contention on Windows
  + Added synchronization to RunCommand service stop
  + Changed hibernation log level
  + MacOS executables are now signed
  + Removed delay in non-interactive session type
* Wed May 19 2021 Robert Schweikert <rjschwei@suse.com>
- Update to version 3.0.1209.0 (bsc#1186239, bsc#1186262)
  + For detailed changes see RELEASENOTES.md
  + Drop fix-version.patch replaced by sed expression in spec file
  + Drop remove-unused-import.patch no longer included from upstream
  + Drop fix-config.patch all SUSE distros use systemd
  + Remove amazon-ssm-agent.service included in upstream source, use it
  + Move all binaries into sbin and fix the hard coded config path via sed
* Wed May 27 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.3.1205.0:
  * Updated the SSM Agent Snap to core18
  * Bug fix for expired in-progress documents being resumed
  * Bug fix for update specific files not being deleted after agent update is finished
  * Bug fix for cached manifest files not being deleted in the configurepackage plugin
* Thu Apr 30 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.3.978.0 (2020-04-08) (bsc#1170744)
  + Stop pty on receiving TerminateSession request
  + Add support for Debian arm64 architecture
  + Refactoring session log generation logic
- Update to 2.3.930.0  (2020-03-17)
  + Bug fix for CloudWatch agent version showing twice in Inventory console
  + Bug fix for retrieving minor version for CentOS7
  + Add snap appData collection for inventory in ubuntu 18
  + Add validation for contents of os release files
  + Add retry for fingerprint generation
- Update to 2.3.871.0 (2020-02-20)
  + Various bug fix for SSM Agent
- Update to 2.3.842.0 (2020-01-29)
  + Bug fix for updating document state file prior agent reboot
  + Add support to restart agent after SIGPIPE exit status
- Update to 2.3.814.0 (2020-01-16)
  + Bug fix for metadata service V2
  + Update Golang version 1.12 for travis
  + Optimize session manager retry logic
- Update to 2.3.786.0 (2019-12-19)
  + Add support for Oracle Linux v7.5 and v7.7
  + Bug fix for Inventory data provider to support special characters
  + Bug fix for SSM MDS service name
- Update to 2.3.772.0 (2019-12-13)
  + Upgrade AWS SDK
  + Add logging for fingerprint generation
- Update to 2.3.760.0 (2019-11-15)
  + Session manager supports handling of Task metadata
- Update to 2.3.758.0 (2019-11-11)
  + Add support to update SSM Distributor packages in place
- Update to 2.3.756.0 (2019-11-05)
  + Terminate port forwarding session on receiving TerminateSession flag
  + Bug fix to reload SSM client if region has not been initialize correctly
  + Bug fix for retrieval of user groups on Linux
- Update to 2.3.722.0 (2019-10-11)
  + Bug fix for the delay when registering non-EC2 on-prem instances
  + Bug fix for missing ACL when uploading logs to S3 buckets
  + Upgrade GoLang version from 1.9 to 1.12
- Update to 2.3.714.0 (2019-09-26)
  + For port forwarding session, close server connection when client drops it's connection
  + Bug fix for missing condition of rules from inventory registry
  + Update service domain information fetch logic from EC2 Metadata
- Update to 2.3.707.0 (2019-09-11)
  + Bug fix for characters dropping from session manager shell output
  + Bug fix for session manager freezing caused by non utf8 character
  + Switch the request protocol order for getting S3 Header
  + Keep port forwarding session open until session is terminated
- Update to 2.3.701.0 (2019-08-21)
  + Send platform type information in controlChannel input
- Update to 2.3.687.0 (2019-08-05)
  + Bug fix for runPowershellScript plugin on linux platform
  + Add support for document 2.x version to ssm-cli
- Update to 2.3.680.0 (2019-07-24)
  + Added a new Inventory gatherer AWS:BillingInfo which will gather the billing product ids for LicenseIncluded and Marketplace instance
- Update to 2.3.672.0 (2019-07-09)
  + Add Port plugin for SSH/SCP
  + Add support for Session Manager RunAs functionality on Linux platform
- Update to 2.3.668.0 (2019-07-01)
  + Add Session Manager InteractiveCommands plugin
  + Bug fix for log formatting issue for session manager
- Update to 2.3.662.0 (2019-06-19)
  + Bug fix for Session Manager when handling line endings on Windows platform
  + Bug fix for token validation for aws:downloadContent plugin
  + Check if log group exists before uploading Session Manager logs to CloudWatch
  + Bug fix for broken S3 urls when using custom documents
- Update to 2.3.634.0 (2019-05-28)
  + Disable appconfig to load credential from specific profile path, add EC2 credentials as the default fallback
  + Remove sudoers file creation logic if ssm-user already exists
  + Enable supplementary groups for ssm-user on Linux
- Update to 2.3.612.0 (2019-05-08)
  + Bug fix for UTF-8 encoded issue caused by locale activation on Ubuntu 16.04 instance
  + Refactor ssm-user creation logic
  + Bug fix for reporting IP address with wrong network interface
  + Update configure package document arn pattern
- Update to 2.3.542.0 (2019-04-18)
  + Bug fix for on-premises instance registration in CN region
- Update to 2.3.539.0 (2019-04-04)
  + Add support for further encryption of session data using AWS KMS
  + Bug fix for excessive instance-id fetching by document workers
- Update to 2.3.479.0 (2019-03-06)
  + Bug fix for downloading content failure caused by wrong S3 endpoint
  + Bug fix for reboot failure caused by session manager panic
  + Bug fix for session manager shell output dropping character
  + Bug fix for mgs endpoint configuration consistency
- Update to 2.3.444.0 (2019-02-10)
  + Updates to UpdateInstanceInformation call, Windows initialization
- Add patch to remove unused import
  + remove-unused-import.patch
- Refresh patches for new version
  + fix-version.patch
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut through the -mini flavors.
* Wed Mar  6 2019 Sean Marlow <sean.marlow@suse.com>
- Update version patch.
- Update to 2.3.415.0 (2019-03-05)
  + Bug fix addressing issues in Distributor package upgrade
- Update to 2.3.372.0 (2019-03-05)
  + Bug fix to allow installation of Distributor packages that do
    not have a version name.
  + Bug fix for agent crash with message "WaitGroup is reused
    before previous Wait has returned".
- Update to 2.3.344.0 (2019-03-05)
  + Add frequent collector to detect changed inventory types and
    upload it to SSM service between two scheduled collections.
  + Change AWS Systems Manager Distributor to reduce calls to
    GetDocument by calling DescribeDocument.
  + Add exit code when ssm-cli execution fails.
  + Create ssm-user only after the control channel has been
    successfully created.
- Update to 2.3.274.0 (2019-03-05)
  + Enabled AWS Systems Manager Distributor that lets you securely
    distribute and install software packages.
  + Add support for the arm64 architecture on Amazon Linux 2,
    Ubuntu 16.04/18.04, and RHEL 7.6 to support EC2 A1 instances.
- Update to 2.3.235.0 (2019-03-05)
  + Bug fix for session manager logging on Windows
  + Bug fix for ConfigureCloudWatch plugin
  + Bug fix for update SSM agent occasionally failing due to SSM
    agent service stuck in starting state
- Update to 2.3.193.0 (2019-03-05)
  + Bug fix for past sessions occasionally stuck in terminating
    state
  + Darwin masquerades as Linux to bypass OS validation on the
    backend until official support can be added
- Update to 2.3.169.0 (2019-03-05)
  + Update managed instance role token more frequently
- Update to 2.3.136.0 (2019-03-05)
  + Bug fix for issue that GatherInventory throw out error when
    there is no Windows Update in instance
  + Add more filters when getting the Windows event logs at
    startup to improve performance
  + Add random jitter before call PutInventory in inventory
    datauploader
- Update to 2.3.117.0 (2019-03-05)
  + Bug fix for issues during process termination on instances
    where IAM policy does not grant ssmmessages permissions.
- Update to 2.3.101.0 (2019-03-05)
  + Bug fix to prevent defunct processes when creating the local
    user ssm-user.
  + Bug fix for sudoersFile permission to avoid "sudo" command
    warnings in Session Manager.
  + Disable hibernation on Windows platform if Cloudwatch
    configuration is present.
- Update to 2.3.68.0 (2019-03-05)
  + Enables the Session Manager capability that lets you manage
    your Amazon EC2 instance through an interactive one-click
    browser-based shell or through the AWS CLI.
  + Beginning this agent version, SSM Agent will create a local
    user "ssm-user" and either add it to /etc/sudoers (Linux) or
    to the Administrators group (Windows) every time the agent
    starts. The ssm-user is the default OS user when a Session
    Manager session is started, and the password for this user is
    reset on every session. You can change the permissions by
    moving the ssm-user to a less-privileged group or by changing
    the sudoers file. The ssm-user is not removed from the system
    when SSM Agent is uninstalled.
- Update to 2.3.13.0 (2019-03-05)
  + Bug fix for the SSM Agent service remaining in "Starting"
    state on Windows when unable to authenticate to the Systems
    Manager service.
- Update to 2.2.916.0 (2019-03-05)
  + Bug fix for missing cloudwatch.exe seen in SSM Agent version
    2.2.902.0
- Update to 2.2.902.0 (2019-03-05)
  + Initial support for developer builds on macOS
  + Retry sending Run Command execution results for up to 2 hours
  + More detailed error messages are returned for inventory plugin
    failures during State Manager association executions
- Update to 2.2.800.0 (2019-03-05)
  + Bug fix to clean the orchestration directory
  + Streaming AWS Systems Manager Run Command output to CloudWatch
    Logs
  + Reducing number of retries for serial port opening
  + Add retry logic to installation verification
- Update to 2.2.619.0 (2019-03-05)
  + Various bug fixes
- Update to 2.2.607.0 (2019-03-05)
  + Various bug fixes
- Update to 2.2.546.0 (2019-03-05)
  + Bug fix to retry sending document results if they couldn't
    reach the service
- Update to 2.2.493.0 (2019-03-05)
  + Added support for Ubuntu Snap packaging
  + Bug fix so that aws:downloadContent does not change permissions
    of directories
  + Bug fix to Cloudwatch plugin where StartType has duplicated
    Enabled value
- Update to 2.2.392.0 (2019-03-05)
  + Added support for agent hibernation so that Agent backs off or
    enters hibernation mode if it does not have access to the
    service
  + Various bug fixes
- Update to 2.2.355.0 (2019-03-05)
  + Fix S3Download to download from cross regions.
  + Various bug fixes
* Wed Mar 14 2018 sean.marlow@suse.com
- Update to 2.2.325.0 2018-03-07 (bsc#1085670)
  + Bug fix to change sourceHashType to be default sha256 on
    psmodule.
- Update to 2.2.257.0 2018-02-23
  + Bug fix to address an issue that can prevent the agent from
    processing associations after a restart.
- Update to 2.2.160.0 2018-01-15
  + Execute "pwsh" on linux when using runPowershellScript plugin.
- Update to 2.2.93.0 2017-11-14
  + Update to latest AWS SDK.
- Update to 2.2.58.0 2017-10-23
  + Switching to use Birdwatcher distribution service for AWS
    packages.
* Thu Feb  1 2018 ro@suse.de
- do not build on s390, only on s390x (no go on s390)
* Mon Nov 27 2017 sean.marlow@suse.com
- Update Go version requirement to 1.7.4.
* Wed Nov  8 2017 sean.marlow@suse.com
- Add ssm-document-worker binary to agent package.
* Wed Nov  8 2017 sean.marlow@suse.com
- Update to 2.2.45.0 2017-10-18 (bsc#1067256)
  + Refresh version patch with new version.
  + Adding versioning support for Parameter Store.
  + Added additional gatherers for inventory, including windows
    service gatherer, windows registry gatherer, file metadata
    gatherer, windows role gatherer.
  + Added support for aws:downloadContent plugin to download
    content from GitHub, S3 and documents from SSM documents.
  + Added support for aws:runDocument plugin to execute SSM
    documents.
- Update to 2.2.30.0 2017-10-09
  + Improved speed of initial association application on boot
  + Various aws:configurePackage service integration changes
  + Improved home directory detection in non-x64 linux platforms
    to address cases where shared AWS SDK credentials were not
    available in on-prem instances
- Update to 2.2.24.0 2017-10-02
  + Added exponential backoff in bucket region check for s3 upload
  + Fixed an issue with orchestration directory cleanup for
    RunCommand
- Update to 2.2.16.0 2017-09-25
- Update to 2.1.4.0 2017-09-11
  + Support for command execution out-of-process
- Update to 2.0.952.0 2017-08-28
* Fri Aug 25 2017 sean.marlow@suse.com
- Add ssm-cli to package.
- Remove requirement on lsb-release. Agent now parses os-release
  by default.
- Use gzip archive from GitHub instead of converting to xz.
- Update to 2.0.922.0 2017-08-14 (bsc#1055766)
  + Added Raspbian support for armv6 to support Raspberry Pi
  + Various bug fixes
- Update to 2.0.913.0 2017-08-07
  + Updated golang/sys dependency to the latest
  + Increased run command document maximum execution timeout to 48 hours
  + Various bug fixes
- Update to 2.0.902.0 2017-07-31
  + Added support for uploading agent logs to CloudWatch for SSM Agent diagnostics
  + Added additional gatherers for inventory
  + Added configuration compliance support for association
  + Various bug fixes
- Update to 2.0.879.0 2017-07-26
  + Add capability to configure custom s3 endpoint for the agent
  + Various bug fixes
- Update to 2.0.847.0 2017-07-03
  + Various bug fixes
- Update to 2.0.842.0 2017-06-26
  + Added rollback support in aws:configurePackage
  + Various bug fixes
- Update to 2.0.834.0 2017-06-23
  + Various bug fixes
- Update to 2.0.805.0 2017-06-07
  + Added support for SLES (SUSE) (64-bit, v12 and above)
  + Various bug fixes
- Update to 2.0.796.0 2017-05-29
  + Linux platform version now based on os-release when available
  + Various bug fixes
* Wed May 31 2017 sean.marlow@suse.com
- Update to 2.0.790.0 2017-05-31 (bsc#1047581)
  - Added support for step-level preconditions
  - Added support for rate/interval based schedule expressions for
    associations
  - Added Summary and PackageID fields to inventory's
    aws:application gatherer
  - Changed inventory's aws:application gatherer to use
    win32_processor: addressWidth to detect OS architecture to
    avoid localization based errors
  - Fixed CloudWatch issue with large configuration
  - Fixed S3 upload when instance and bucket are not in the same
    region
  - Fixed bug that prevented native language AMIs (Japanese AMI)
    from launching Cloudwatch
  - Various bug fixes
- Update to 2.0.767.0 2017-05-31
  - Returning longer StandardOutput and StandardError from
    RunShellScript and RunPowerShellScript which show up in the
    results of GetCommandInvocation and the detailed output of
    ListCommandInvocation
  - Added Document v2.0 support for Run Command, which includes
    support for multiple actions of same plugin type
  - Various bug fixes
- Update to 2.0.755.0 2017-05-31
  - Fixed bugs that prevented CloudWatch from launching and allowed
    multiple instances of CloudWatch to launch on Windows
  - Various bug fixes
- Update to 2.0.730.0 2017-05-31
  - Fixed issues with agent starting before network is ready on
    systemd systems.
- Update to 2.0.716.0 2017-05-31
  - Pass proxy settings to domain join and CloudWatch
  - Added support for installing Docker on Linux
  - Removed the upper limit for the maximum number of parallel
    executing documents on the agent (previously the max was 10)
  - You can configure this number by setting the
    “CommandWorkerLimit” attribute in amazon-ssm-agent.json file
  - Various bug fixes
* Wed Mar  1 2017 lchiquitto@suse.de
- Add package to SLE-12 codestream (bsc#1017899, fate#322303)
* Fri Feb 17 2017 sean.marlow@suse.com
- Update to 2.0.672.0 2017-02-17
  - Added bucket-owner-full-control ACL to S3 outputs to support
    cross-account upload
  - Standardized S3 result paths across plugins; commands append
    command-id/instance-id/plugin-name/step-id associations append
    instance-id/association-id/execution-date/plugin-name/step-id
  - step-id is the id field in plugin input if present and
    supported, otherwise the step name (in 2.0 schema documents),
    otherwise the plugin-name again
  - plugin-name and step-id have : characters removed
  - FreeBSD patches from external contributor
  - Various bug fixes
* Thu Jan 19 2017 sean.marlow@suse.com
- Update to 2.0.663.0 2017-01-18
  - Added support for aws:softwareInventory plugin to upload
    inventory related log messages to S3
  - Added support for running Powershell on Linux
  - Added support for State Manager that automates the process of
    keeping your Amazon EC2 and hybrid infrastructure in a state that
    you define You can use State Manager to ensure that your instances
    are bootstrapped with specific software at startup, configured
    according to your security policy, joined to a Windows domain,
    or patched with specific software updates throughout their
    lifecycle
  - Added support for Systems Manager Inventory that allows you to
    specify the type of metadata to collect, the instances from
    where the metadata should be collected, and a schedule for
    metadata collection
  - Added support for installing, uninstalling, and updating AWS
    packages published by AWS
  - Added support for installing Docker on Windows and running
    Docker actions
  - Added support for Windows Server 2016
  - Added support for Windows Server Nano
  - Fixed CloudWatch crash issue
  - Fixed Domain Join to support customized OU
  - Fixed CloudWatch doesn't work with creating association from
    Console
  - Fixed SSM Agent not able to start on Windows Server 2003
  - Various bug fixes
* Fri Dec 16 2016 sean.marlow@suse.com
- Initial package 1.2.290.0 2016-07-20
